@@ -32,10 +32,6 @@
 
 #include "common_indep.h"
 
-#include <gpgme++/context.h>
-#include <gpgme++/error.h>
-#include <gpgme++/configuration.h>
-
 #ifdef HAVE_W32_SYSTEM
 # include "common.h"
 # include <windows.h>
@@ -128,59 +124,6 @@ cArray_to_vector(const char **cArray)
   return ret;
 }
 
-bool
-in_de_vs_mode()
-{
-/* We cache the values only once. A change requires restart.
-     This is because checking this is very expensive as gpgconf
-     spawns each process to query the settings. */
-  static bool checked;
-  static bool vs_mode;
-
-  if (checked)
-    {
-      return vs_mode;
-    }
-  checked = true;
-  GpgME::Error err;
-  const auto components = GpgME::Configuration::Component::load (err);
-  log_debug ("%s:%s: Checking for de-vs mode.",
-             SRCNAME, __func__);
-  if (err)
-    {
-      log_error ("%s:%s: Failed to get gpgconf components: %s",
-                 SRCNAME, __func__, err.asString ());
-      vs_mode = false;
-      return vs_mode;
-    }
-  for (const auto &component: components)
-    {
-      if (component.name () && !strcmp (component.name (), "gpg"))
-        {
-          for (const auto &option: component.options ())
-            {
-              if (option.name () && !strcmp (option.name (), "compliance") &&
-                  option.currentValue ().stringValue () &&
-#ifdef HAVE_W32_SYSTEM
-                  !stricmp (option.currentValue ().stringValue (), "de-vs"))
-#else
-                  !strcasecmp (option.currentValue ().stringValue (), "de-vs"))
-#endif
-                {
-                  log_debug ("%s:%s: Detected de-vs mode",
-                             SRCNAME, __func__);
-                  vs_mode = true;
-                  return vs_mode;
-                }
-            }
-          vs_mode = false;
-          return vs_mode;
-        }
-    }
-  vs_mode = false;
-  return false;
-}
-
 #ifdef HAVE_W32_SYSTEM
 std::map<std::string, std::string>
 get_registry_subkeys (const char *path)
@@ -360,3 +303,27 @@ bool starts_with(const std::string &s, const char prefix)
 {
   return !s.empty() && s.front() == prefix;
 }
+
+static std::string
+do_asprintf_s (const char *fmt, va_list a)
+{
+  char *buf;
+  if (gpgrt_vasprintf (&buf, fmt, a) < 0)
+    {
+      STRANGEPOINT;
+      return std::string ();
+    }
+  std::string ret (buf);
+  free (buf);
+  return ret;
+}
+
+std::string
+asprintf_s (const char *fmt, ...)
+{
+  va_list a;
+  va_start (a, fmt);
+  std::string ret = do_asprintf_s (fmt, a);
+  va_end (a);
+  return ret;
+}
