@@ -45,7 +45,7 @@ class subcls : public parentcls                                          \
   inline STDMETHODIMP_(ULONG) AddRef (void)                              \
     {                                                                    \
       ++m_ref;                                                           \
-      if (debug_oom_extra)                                               \
+      if ((opt.enable_debug & DBG_OOM))                                               \
         log_debug ("%s:" #subcls ":%s: m_ref now %lu",                   \
                    SRCNAME,__func__, m_ref);                             \
       return m_ref;                                                      \
@@ -53,7 +53,7 @@ class subcls : public parentcls                                          \
   inline STDMETHODIMP_(ULONG) Release (void)                             \
     {                                                                    \
       ULONG count = --m_ref;                                             \
-      if (debug_oom_extra)                                               \
+      if ((opt.enable_debug & DBG_OOM))                                               \
         log_debug ("%s:" #subcls ":%s: mref now %lu",                    \
                    SRCNAME,__func__,count);                              \
       if (!count)                                                        \
@@ -92,7 +92,7 @@ STDMETHODIMP subcls::Invoke (DISPID dispid, REFIID riid, LCID lcid,      \
 
 #define EVENT_SINK_DEFAULT_DTOR_CODE(subcls)                             \
 {                                                                        \
-  if (debug_oom)                                                         \
+  if ((opt.enable_debug & DBG_OOM))                                                         \
     log_debug ("%s:" #subcls ":%s: dtor", SRCNAME, __func__);            \
   if (m_pCP)                                                             \
     m_pCP->Unadvise(m_cookie);                                           \
@@ -196,7 +196,7 @@ LPDISPATCH install_ ## subcls ## _sink (LPDISPATCH object)               \
       gpgol_release (sink);                                                  \
       return NULL;                                                       \
     }                                                                    \
-  if (debug_oom)                                                         \
+  if ((opt.enable_debug & DBG_OOM))                                                         \
     log_debug ("%s:%s:%s: Advice succeeded", SRCNAME, #subcls, __func__);\
   sink->m_cookie = cookie;                                               \
   sink->m_pCP = pCP;                                                     \
@@ -210,7 +210,7 @@ void detach_ ## subcls ## _sink (LPDISPATCH obj)                         \
   HRESULT hr;                                                            \
   subcls *sink;                                                          \
                                                                          \
-  if (debug_oom_extra)                                                   \
+  if ((opt.enable_debug & DBG_OOM))                                                   \
     log_debug ("%s:%s:%s: Called", SRCNAME, #subcls, __func__);          \
   hr = gpgol_queryInterface (obj, iidcls, (void**)&sink);                \
   if (hr != S_OK || !sink)                                               \
@@ -221,13 +221,13 @@ void detach_ ## subcls ## _sink (LPDISPATCH obj)                         \
     }                                                                    \
   if (sink->m_pCP)                                                       \
     {                                                                    \
-      if (debug_oom_extra)                                               \
+      if ((opt.enable_debug & DBG_OOM))                                               \
         log_debug ("%s:%s:%s: Unadvising", SRCNAME, #subcls, __func__);  \
       hr = sink->m_pCP->Unadvise (sink->m_cookie);                       \
       if (hr != S_OK)                                                    \
         log_error ("%s:%s:%s: Unadvice failed: hr=%#lx",                 \
                    SRCNAME, #subcls, __func__, hr);                      \
-      if (debug_oom_extra)                                               \
+      if ((opt.enable_debug & DBG_OOM))                                               \
         log_debug ("%s:%s:%s: Releasing connt point",                    \
                    SRCNAME, #subcls, __func__);                          \
       gpgol_release (sink->m_pCP);                                           \
@@ -235,7 +235,7 @@ void detach_ ## subcls ## _sink (LPDISPATCH obj)                         \
     }                                                                    \
   if (sink->m_object)                                                    \
     {                                                                    \
-      if (debug_oom_extra)                                               \
+      if ((opt.enable_debug & DBG_OOM))                                               \
         log_debug ("%s:%s:%s: Releasing actual object",                  \
                    SRCNAME, #subcls, __func__);                          \
       gpgol_release (sink->m_object);                                        \
