@@ -122,6 +122,8 @@ DEFINE_OLEGUID(IID_IOleWindow,                0x00000114, 0, 0);
 #define GPGOL_UID_DASL \
   "http://schemas.microsoft.com/mapi/string/" \
   "{31805AB8-3E92-11DC-879C-00061B031004}/GpgOL UID/0x0000001F"
+#define PR_INTERNET_MESSAGE_ID_W_DASL \
+  "http://schemas.microsoft.com/mapi/proptag/0x1035001F"
 #define PR_ATTACH_DATA_BIN_DASL \
   "http://schemas.microsoft.com/mapi/proptag/0x37010102"
 #define PR_BODY_W_DASL \
@@ -150,6 +152,8 @@ DEFINE_OLEGUID(IID_IOleWindow,                0x00000114, 0, 0);
   "http://schemas.microsoft.com/mapi/proptag/0x0C1A001F"
 #define PR_SENT_REPRESENTING_NAME_W_DASL \
   "http://schemas.microsoft.com/mapi/proptag/0x0042001F"
+#define PR_PRIMARY_SEND_ACCT_W_DASL \
+  "http://schemas.microsoft.com/mapi/proptag/0x0E28001F"
 
 #define PR_SECURITY_FLAGS_DASL \
   "http://schemas.microsoft.com/mapi/proptag/0x6E010003"
@@ -452,6 +456,9 @@ char *get_sender_SendUsingAccount (LPDISPATCH mailitem, bool *r_is_GSuite);
 /* Get the SentRepresentingAddress */
 char *get_sender_SentRepresentingAddress (LPDISPATCH mailitem);
 
+/* Get MAPI PR_PRIMARY_SEND_ACCT and parse it to mail. */
+char *get_sender_primary_send_acct (LPDISPATCH mailitem);
+
 /* memtracing query interface */
 HRESULT gpgol_queryInterface (LPUNKNOWN pObj, REFIID riid, LPVOID FAR *ppvObj);
 
